@@ -1,7 +1,7 @@
-/* $Id: bibtexconv.cc 1086 2011-10-27 07:31:44Z dreibh $
+/* $Id: bibtexconv.cc 1346 2012-02-13 15:16:23Z dreibh $
  *
  * BibTeX Converter
- * Copyright (C) 2010-2011 by Thomas Dreibholz
+ * Copyright (C) 2010-2012 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -299,12 +299,18 @@ static std::string              customPrintingTemplate =
    "\\[%C\\] %L\n %a\tAUTHOR: [[%fFIRST|%lLAST|%nNOT-FIRST]: initials=%g given=%G full=%F]\n%A\n";  // ", \"%T\"[, %B][, %J][, %?][, %$][, Volume~%V][, Number~%N][, pp.~%P][, %I][, %i][, %@][, [[%m, %D, |%m~]%Y].\\nURL: %U.\\n\\n";
 static std::vector<std::string> monthNames;
 
-
 static int handleInput(FILE*           fh,
                        PublicationSet& publicationSet,
                        const char*     downloadDirectory,
                        const bool      checkURLs,
                        const bool      checkNewURLsOnly,
+                       const char*     exportToBibTeX,
+                       const char*     exportToSeparateBibTeXs,
+                       const char*     exportToXML,
+                       const char*     exportToSeparateXMLs,
+                       const bool      skipNotesWithISBNandISSN,
+                       const bool      addNotesWithISBNandISSN,
+                       const bool      addUrlCommand,
                        unsigned int    recursionLevel = 0)
 {
    int result = 0;
@@ -397,13 +403,49 @@ static int handleInput(FILE*           fh,
             if(checkURLs) {
                result += checkAllURLs(&publicationSet, downloadDirectory, checkNewURLsOnly);
             }
+            const char* namingTemplate = "%u";
+            if(input[6] == ' ') {
+               namingTemplate = (const char*)&input[7];
+            }
+
+            // ====== Export all to custom ==================================
             if(PublicationSet::exportPublicationSetToCustom(
-                  &publicationSet,
+                  &publicationSet, namingTemplate,
                   customPrintingHeader, customPrintingTrailer,
                   customPrintingTemplate, monthNames, nbsp, useXMLStyle,
                   downloadDirectory, stdout) == false) {
                result++;
             }
+
+            // ====== Export all to BibTeX ==================================
+            if(exportToBibTeX) {
+               if(PublicationSet::exportPublicationSetToBibTeX(
+                  &publicationSet, exportToBibTeX, false,
+                  skipNotesWithISBNandISSN, addNotesWithISBNandISSN, addUrlCommand) == false) {
+                  exit(1);
+               }
+            }
+            if(exportToSeparateBibTeXs) {
+               if(PublicationSet::exportPublicationSetToBibTeX(
+                  &publicationSet, exportToSeparateBibTeXs, true,
+                  skipNotesWithISBNandISSN, addNotesWithISBNandISSN, addUrlCommand) == false) {
+                  exit(1);
+               }
+            }
+
+            // ====== Export all to XML =====================================
+            if(exportToXML) {
+               if(PublicationSet::exportPublicationSetToXML(
+                  &publicationSet, exportToXML, false) == false) {
+                  exit(1);
+               }
+            }
+            if(exportToSeparateXMLs) {
+               if(PublicationSet::exportPublicationSetToXML(
+                  &publicationSet, exportToSeparateXMLs, true) == false) {
+                  exit(1);
+               }
+            }
          }
          else if((strncmp(input, "clear", 5)) == 0) {
             publicationSet.clearAll();
@@ -442,6 +484,10 @@ static int handleInput(FILE*           fh,
                if(includeFH != NULL) {
                   result += handleInput(includeFH, publicationSet,
                                         downloadDirectory, checkURLs, checkNewURLsOnly,
+                                        exportToBibTeX, exportToSeparateBibTeXs,
+                                        exportToXML, exportToSeparateXMLs,
+                                        skipNotesWithISBNandISSN, addNotesWithISBNandISSN,
+                                        addUrlCommand,
                                         recursionLevel + 1);
                   fclose(includeFH);
                }
@@ -578,56 +624,61 @@ int main(int argc, char** argv)
          if(checkURLs) {
             result += checkAllURLs(&publicationSet, downloadDirectory, checkNewURLsOnly);
          }
-
-         // ====== Export all to BibTeX =====================================
-         if(exportToBibTeX) {
-            if(PublicationSet::exportPublicationSetToBibTeX(
-               &publicationSet, exportToBibTeX, false,
-               skipNotesWithISBNandISSN, addNotesWithISBNandISSN, addUrlCommand) == false) {
-               exit(1);
-            }
-         }
-         if(exportToSeparateBibTeXs) {
-            if(PublicationSet::exportPublicationSetToBibTeX(
-               &publicationSet, exportToSeparateBibTeXs, true,
-               skipNotesWithISBNandISSN, addNotesWithISBNandISSN, addUrlCommand) == false) {
-               exit(1);
-            }
-         }
-
-         // ====== Export all to XML ========================================
-         if(exportToXML) {
-            if(PublicationSet::exportPublicationSetToXML(
-               &publicationSet, exportToXML, false) == false) {
-               exit(1);
-            }
-         }
-         if(exportToSeparateXMLs) {
-            if(PublicationSet::exportPublicationSetToXML(
-               &publicationSet, exportToSeparateXMLs, true) == false) {
-               exit(1);
-            }
-         }
-
-         // ====== Export all to custom format ==============================
-         if(exportToCustom) {
-            if(PublicationSet::exportPublicationSetToCustom(
-                  &publicationSet,
-                  customPrintingHeader, customPrintingTrailer,
-                  customPrintingTemplate, monthNames,
-                  nbsp, useXMLStyle, downloadDirectory,
-                  stdout) == false) {
-               exit(1);
-            }
-         }
       }
       else {
          fprintf(stderr, "Got %u publications from BibTeX file.\n",
                  (unsigned int)publicationSet.maxSize());
          result = handleInput(stdin, publicationSet,
-                              downloadDirectory, checkURLs, checkNewURLsOnly);
+                              downloadDirectory, checkURLs, checkNewURLsOnly,
+                              exportToBibTeX, exportToSeparateBibTeXs,
+                              exportToXML, exportToSeparateXMLs,
+                              addUrlCommand,
+                              skipNotesWithISBNandISSN, addNotesWithISBNandISSN);
          fprintf(stderr, "Done. %u errors have occurred.\n", result);
       }
+
+
+      // ====== Export all to BibTeX ========================================
+      if(exportToBibTeX) {
+         if(PublicationSet::exportPublicationSetToBibTeX(
+            &publicationSet, exportToBibTeX, false,
+            skipNotesWithISBNandISSN, addNotesWithISBNandISSN, addUrlCommand) == false) {
+            exit(1);
+         }
+      }
+      if(exportToSeparateBibTeXs) {
+         if(PublicationSet::exportPublicationSetToBibTeX(
+            &publicationSet, exportToSeparateBibTeXs, true,
+            skipNotesWithISBNandISSN, addNotesWithISBNandISSN, addUrlCommand) == false) {
+            exit(1);
+         }
+      }
+
+      // ====== Export all to XML ===========================================
+      if(exportToXML) {
+         if(PublicationSet::exportPublicationSetToXML(
+            &publicationSet, exportToXML, false) == false) {
+            exit(1);
+         }
+      }
+      if(exportToSeparateXMLs) {
+         if(PublicationSet::exportPublicationSetToXML(
+            &publicationSet, exportToSeparateXMLs, true) == false) {
+            exit(1);
+         }
+      }
+
+      // ====== Export all to custom format =================================
+      if(exportToCustom) {
+         if(PublicationSet::exportPublicationSetToCustom(
+               &publicationSet, "%u",
+               customPrintingHeader, customPrintingTrailer,
+               customPrintingTemplate, monthNames,
+               nbsp, useXMLStyle, downloadDirectory,
+               stdout) == false) {
+            exit(1);
+         }
+      }
    }
    if(bibTeXFile) {
       freeNode(bibTeXFile);
